==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/he-IL/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'כבר קיים חשבון עם האימייל הזה.',
    'account_not_found'      => 'שם המשתמש או הסיסמה שגויים.',
    'account_not_activated'  => 'חשבון משתמש זה אינו מופעל.',
    'account_suspended'      => 'חשבון המשתמש הזה מושעה.',
    'account_banned'         => 'חשבון משתמש זה מוחרם.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'התחברת בהצלחה.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'אירעה בעיה בעת ניסיון להתחבר אליך, נסה שוב.',
        'success' => 'התחברת בהצלחה.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'אירעה בעיה בעת ניסיון ליצור את חשבונך, נסה שוב.',
        'success' => 'החשבון נוצר בהצלחה.',
    ),

    'forgot-password' => array(
        'error'   => 'אירעה בעיה בעת ניסיון לקבל קוד סיסמה לאיפוס, נסה שוב.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'אירעה בעיה בעת ניסיון לאפס את הסיסמה שלך, נסה שוב.',
        'success' => 'הסיסמה שלך אופסה בהצלחה.',
    ),


);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/he-IL/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'כבר קיים חשבון עם האימייל הזה.',
    'account_not_found'      => 'שם המשתמש או הסיסמה שגויים.',
    'account_not_activated'  => 'חשבון משתמש זה אינו מופעל.',
    'account_suspended'      => 'חשבון המשתמש הזה מושעה.',
    'account_banned'         => 'חשבון משתמש זה מוחרם.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'התחברת בהצלחה.',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'אירעה בעיה בעת ניסיון להתחבר אליך, נסה שוב.',
        'success' => 'התחברת בהצלחה.',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'אירעה בעיה בעת ניסיון ליצור את חשבונך, נסה שוב.',
        'success' => 'החשבון נוצר בהצלחה.',
    ),

    'forgot-password' => array(
        'error'   => 'אירעה בעיה בעת ניסיון לקבל קוד סיסמה לאיפוס, נסה שוב.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'אירעה בעיה בעת ניסיון לאפס את הסיסמה שלך, נסה שוב.',
        'success' => 'הסיסמה שלך אופסה בהצלחה.',
    ),


);
